unit Unit1;

interface

uses
  System.SysUtils, System.Classes,

  Vcl.Forms, Vcl.Controls, Vcl.StdCtrls, Vcl.ExtCtrls,

  VCLTee.TeEngine, VCLTee.TeeTools, VCLTee.Chart, VCLTee.Series,
  VCLTee.TeePolar, VCLTee.TeeSeriesBandTool, VclTee.TeeGDIPlus,
  VCLTee.TeeProcs
;

type

	TForm1 = class(TForm)
		Timer1: TTimer;
		FlowPanel1: TFlowPanel;
		doRotationCheckbox: TCheckBox;
		crazyCheckbox: TCheckBox;
		Chart: TChart;
		firstSeries: TPolarSeries;
		secondSeries: TPolarSeries;
    seriesBandTool: TSeriesBandTool;

		procedure FormCreate(Sender: TObject);
		procedure Timer1Timer(Sender: TObject);
		procedure doRotationCheckboxClick(Sender: TObject);

		private const
			degStart: Single = 90.0;
		private var
			secondSeriesRotation: Single;
		private
			procedure initSeries();

		protected
			function calcChartValue(
				const degPos: Single;
				const offset: Single = 0.0
			): Single;
			procedure rotateSeries();
			procedure paintSeries(
				const Series: TPolarSeries;
				const offset: Single
			); virtual;
	end;

var
  Form1: TForm1;

implementation uses System.Math;

{$R *.dfm}

procedure TForm1.FormCreate(Sender: TObject);
const
	/// <remarks>
	///     Bigger means "graph seems less extreme"
	/// </remarks>
	zoomFactor: Single = 2.0;
begin
	chart.Axes.Left.SetMinMax(-zoomFactor, +zoomFactor);
	chart.Axes.Bottom.SetMinMax(-zoomFactor, +zoomFactor);
	initSeries();
	doRotationCheckbox.Checked := Timer1.Enabled;

end;

procedure TForm1.Timer1Timer(Sender: TObject);
begin
	if crazyCheckbox.Checked then
		secondSeries.Rotate(-1)
	else
		rotateSeries();
end;

procedure TForm1.rotateSeries();
var
	degPos: Single;
begin
	secondSeriesRotation := secondSeriesRotation + 0.1;
	paintSeries(secondSeries, secondSeriesRotation);
end;

function TForm1.calcChartValue(const degPos, offset: Single): Single;
const
	times: Integer = 4;
begin
	Result := Sin( DegToRad(degPos)*times + offset );
	Result := 1.0 + Result;
end;


procedure TForm1.doRotationCheckboxClick(Sender: TObject);
begin
	Timer1.Enabled := doRotationCheckbox.Checked;
end;

procedure TForm1.paintSeries(const series: TPolarSeries; const offset: Single);
const
	degPosStep: Single = 10.0;
var
	degPos: Single;
begin
	Assert( Assigned(series) );
	series.Clear();

	degPos := degStart;

	while degPos <= 360.0 do begin
		series.AddPolar( degPos, calcChartValue(degPos, offset) );
		degPos := degPos + degPosStep;
	end;
end;

procedure TForm1.initSeries();
begin
	secondSeriesRotation := Pi();
	paintSeries(firstSeries, 0.0);
	paintSeries(secondSeries, secondSeriesRotation);
end;


end.
